@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.104_02';
+our $VERSION = '0.104_03';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sat Sep  1 14:50:05 2018 GMT
+# on Sun Sep  2 12:56:50 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1729,7 +1729,7 @@ __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
 __PACKAGE__->status( add => 25078, iridium => '-', 'Iridium 44', 'Tumbling' );
 __PACKAGE__->status( add => 25104, iridium => '+', 'Iridium 45', '' );
 __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
-__PACKAGE__->status( add => 25106, iridium => '-', 'Iridium 47', 'Tumbling' );
+__PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-09-01' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 14
 #       Spare [S]: 14
-#    Tumbling [-]: 36
-#     Decayed [D]: 33
+#    Tumbling [-]: 35
+#     Decayed [D]: 34
 
 1;
 
